
From: Tom Rini <trini@kernel.crashing.org>

The following adds support for Freescale's PQ2FADS board to the kernel.

(The 'real' changes required for the board are in the ethernet driver,
which needs a massive sync-up with mainline as I've been holding out for a
better, rewritten one from the Freescale folks, who're waiting for the PHY
lib patch sent to the net-dev list to get ack'd)

Signed-off-by: Tom Rini <trini@kernel.crashing.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc/Kconfig            |    8 +++++++-
 25-akpm/arch/ppc/platforms/pq2ads.h |    2 ++
 25-akpm/include/asm-ppc/mpc8260.h   |    2 +-
 3 files changed, 10 insertions(+), 2 deletions(-)

diff -puN arch/ppc/Kconfig~ppc32-add-freescale-pq2fads-support arch/ppc/Kconfig
--- 25/arch/ppc/Kconfig~ppc32-add-freescale-pq2fads-support	Wed Jan 12 16:38:53 2005
+++ 25-akpm/arch/ppc/Kconfig	Wed Jan 12 16:38:53 2005
@@ -623,6 +623,12 @@ config TQM8260
 config ADS8272
 	bool "ADS8272"
 
+config PQ2FADS
+	bool "Freescale-PQ2FADS"
+	help
+	  Select PQ2FADS if you wish to configure for a Freescale
+	  PQ2FADS board (-VR or -ZU).
+
 config LITE5200
 	bool "Freescale LITE5200 / (IceCube)"
 	select PPC_MPC52xx
@@ -655,7 +661,7 @@ config PPC_MPC52xx
 config 8260
 	bool "CPM2 Support" if WILLOW
 	depends on 6xx
-	default y if TQM8260 || RPX8260 || EST8260 || SBS8260 || SBC82xx
+	default y if TQM8260 || RPX8260 || EST8260 || SBS8260 || SBC82xx || PQ2FADS
 	help
 	  The MPC8260 is a typical embedded CPU made by Motorola.  Selecting
 	  this option means that you wish to build a kernel for a machine with
diff -puN arch/ppc/platforms/pq2ads.h~ppc32-add-freescale-pq2fads-support arch/ppc/platforms/pq2ads.h
--- 25/arch/ppc/platforms/pq2ads.h~ppc32-add-freescale-pq2fads-support	Wed Jan 12 16:38:53 2005
+++ 25-akpm/arch/ppc/platforms/pq2ads.h	Wed Jan 12 16:38:53 2005
@@ -40,6 +40,8 @@
 #define BCSR1_FETH_RST		((uint)0x04000000)	/* 0 == reset */
 #define BCSR1_RS232_EN1		((uint)0x02000000)	/* 0 == enable */
 #define BCSR1_RS232_EN2		((uint)0x01000000)	/* 0 == enable */
+#define BCSR3_FETHIEN2		((uint)0x10000000)	/* 0 == enable */
+#define BCSR3_FETH2_RST 	((uint)0x80000000)	/* 0 == reset */
 
 #define PHY_INTERRUPT	SIU_INT_IRQ7
 
diff -puN include/asm-ppc/mpc8260.h~ppc32-add-freescale-pq2fads-support include/asm-ppc/mpc8260.h
--- 25/include/asm-ppc/mpc8260.h~ppc32-add-freescale-pq2fads-support	Wed Jan 12 16:38:53 2005
+++ 25-akpm/include/asm-ppc/mpc8260.h	Wed Jan 12 16:38:53 2005
@@ -36,7 +36,7 @@
 #include <platforms/tqm8260.h>
 #endif
 
-#ifdef CONFIG_PQ2ADS
+#if defined(CONFIG_PQ2ADS) || defined (CONFIG_PQ2FADS)
 #include <platforms/pq2ads.h>
 #endif
 
_
